@@ -312,8 +312,17 @@ def main():
         physio_data.save_to_bids_with_trigger(args.bidsprefix)
     else:
         physio_data.save_to_bids(args.bidsprefix)
+
     if event_data:
-        event_data.save_events_bids_data(args.bidsprefix)
+        if os.path.exists(args.bidsprefix + '_events.tsv'):  #If file already exists, see if it has onset and duration entries
+            pre_file = pd.read_csv(args.bidsprefix + '_events.tsv', sep='\t')
+            if pre_file.columns[0]=='onset' and pre_file.columns[1]=='duration':  #check for a valid BIDS events file
+                setattr(event_data, 'Eyetracker', 'eyetracker')           # so as to know that these task events are from the eyetracker
+                event_data.append_events_bids_data(args.bidsprefix)             #append the new data and order by "onset" and save
+            else:
+                print('Task events file already exists and is not a valid BIDS file')
+        else:   #else just save the data
+            event_data.save_events_bids_data(args.bidsprefix)
     else:
         print('No task events were found')
 
