@@ -2,7 +2,7 @@
 need to also bump up the version of the dependencies
 """
 
-__version__ = "21.05.18"
+__version__ = "21.05.28"
 __author__ = "Chrysa Papadaniil"
 __author_email__ = "chrysa@nyu.edu"
 __url__ = "https://github.com/cbinyu/bidsphysio"
@@ -24,13 +24,14 @@ CLASSIFIERS = [
 PYTHON_REQUIRES = ">=3.6"
 
 REQUIRES = [
-    'bidsphysio.base>=21.4.12',
-    'bidsphysio.session>=21.1.28',
-    'bidsphysio.events>=21.1.28',
+    'bidsphysio.base>=21.5.18',
+    'bidsphysio.session>=21.5.18',
+    'bidsphysio.events>=21.5.27',
     'h5py>=2.9.0',
     'Cython>=0.29.13',
     'pandas>=1.1.0',
-    'numpy>= 1.17.1'
+    'numpy>= 1.20.1',
+    'pyedfread'
 ]
 
 TESTS_REQUIRES = [
